@@ -24,10 +24,6 @@ class Cache:
         Caching process loop
         """
         while 1:
-            if time.time() > self.expat+self.hardexp:
-                raise CachingError("Cache renewal overdue.")
-
-    
             if len(self.cache) > self.maxlen or time.time() > self.expat:
                 self.renew()
 
