@@ -10,5 +10,5 @@ class CommitError(Exception):
     pass
 
 
-class CachingError(Exception):
+class RollbackError(Exception):
     pass
\ No newline at end of file
