@@ -4,6 +4,7 @@ import bcrypt
 import re
 import requests
 import hashlib
+import uuid
 
 
 class Model:
@@ -11,6 +12,27 @@ class Model:
         return ('$MDLREQ', exception)
 
 
+    def _ru(kind):
+        """
+        Do not call.
+        """
+        if kind.lower() == 'int':
+            return uuid.uuid4().int
+        elif kind.lower() == 'hex':
+            return uuid.uuid4().hex
+        elif kind.lower() == 'bytes':
+            return uuid.uuid4().bytes
+        elif kind.lower() == 'node':
+            return uuid.uuid4().node
+        elif kind.upper() == 'UUID':
+            return uuid.uuid4()
+        raise ValueError(f'unknown type "{kind}"')
+
+
+    def RandomUnique(kind='hex'):
+        return ('$MDLRUQ', Model._ru, kind)
+        
+
 def Pickle(obj, legacy=False, *args, **kwargs):
     """
     Make a (pickleable) Python object database writable.
